Skip to contents

The width in bits of one element of the given DataType. For bool this is 1; for complex types it is the total width of the element (c64 -> 64).

Usage

dtype_width(x)

Arguments

x

(DataType)

Value

integer(1)