R/types.R
dtype_width.Rd
The width in bits of one element of the given DataType. For bool this is 1; for complex types it is the total width of the element (c64 -> 64).
DataType
bool
1
c64
64
dtype_width(x)
(DataType)
integer(1)